<?php

namespace Controller;

use Exception\CustomException;
use React\Stream\Util;
use Util\InstanceProvider;
use Util\Utilities;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\HTTP\Kernel;
use Util\Messages;
use Zeedhi\DevOps\Util\Utilities as DevOpsUtilities;


class CustomizationFiles extends Simple
{
    /** @var \Service\CustomizationFiles $productCallService */
    protected $customizationFilesService;

    public function __construct(\Service\CustomizationFiles $customizationFilesService) {
        $this->customizationFilesService = $customizationFilesService;
    }

    public function findCustomizationFiles(Request\Filter $request, Response $response) {
        $params = $request->getFilterCriteria()->getConditions();
        $page = $request->getFilterCriteria()->getPage();
        $pageSize = $request->getFilterCriteria()->getPageSize();
        $orderBy = $request->getFilterCriteria()->getOrderBy();
        try{
            foreach ($params as $param) {
                $name = $param['columnName'];
                if ($name == 'NRLICENCAUSO') {
                    $param['operator'] = 'LIKE';
                }
            }
            $customizationFiles = $this->customizationFilesService->findCustomizationFiles($params, $page, $pageSize,$orderBy);
            $response->addDataSet(new DataSet("customizationFiles", $customizationFiles));
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function findLegalRepresentative(Request\Filter $request, Response $response) {
        $params = $request->getFilterCriteria()->getConditions();
        try{
            $legalRepresentative = $this->customizationFilesService->findLegalRepresentative($params);
            $response->addDataSet(new DataSet("legalRepresentative", $legalRepresentative));
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function findPerValidationDate(Request\Filter $request, Response $response) {
        try{
            $findPerValidationDate = $this->customizationFilesService->findPerValidationDate();
            $response->addDataSet(new DataSet("findPerValidationDate", $findPerValidationDate));
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function findUseLicense(Request\Filter $request, Response $response) {
        try{
            $params = $request->getFilterCriteria()->getConditions();
            $useLicense = $this->customizationFilesService->findUseLicense($params);
            $response->addDataSet(new DataSet("findUseLicense", $useLicense));
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function findPrinterType(Request\Filter $request, Response $response) {
        try{
            $params = $request->getFilterCriteria()->getConditions();
            $filters = DevOpsUtilities::createQueryFiltered($params);
            $printerType = $this->customizationFilesService->findPrinterType($filters);
            $response->addDataSet(new DataSet("findPrinterType", $printerType));
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function findCountry(Request\Filter $request, Response $response) {
        try{
            $conditions = $request->getFilterCriteria()->getConditions();
            $filters = DevOpsUtilities::createQueryFiltered($conditions);
            $country = $this->customizationFilesService->findCountry($filters);
            $response->addDataSet(new DataSet("country", $country));
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function findCity(Request\Filter $request, Response $response) {
        try{
            $params = $request->getFilterCriteria()->getConditions();
            $sgEstado = DevOpsUtilities::getValueInFilterDataSourceByName($params, 'STATE', true);
            $countryId = DevOpsUtilities::getValueInFilterDataSourceByName($params, 'COUNTRY', true);
            $filters = DevOpsUtilities::createQueryFiltered($params);
            $city = $this->customizationFilesService->findCity($sgEstado, $filters, $countryId);
            $response->addDataSet(new DataSet("city", $city));
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function findState(Request\Filter $request, Response $response) {
        try{
            $params = $request->getFilterCriteria()->getConditions();
            $countryId = DevOpsUtilities::getValueInFilterDataSourceByName($params, 'COUNTRY', true);
            $filters = DevOpsUtilities::createQueryFiltered($params);
            $state = $this->customizationFilesService->findState($countryId, $filters);
            $response->addDataSet(new DataSet("state", $state));
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function findCash(Request\Filter $request, Response $response) {
        try{
            $params = $request->getFilterCriteria()->getConditions();
            $licensaUsoId = 0;
            $licensasUso = "";
            foreach ($params as $param) {
                $name = $param['columnName'];
                if ($name == 'LICENCAUSO') {
                    $licensasUso = '%'.Utilities::zeroLeftPadding($param['value'], 10).'%';
                    $cash = $this->customizationFilesService->findCash($licensasUso);

                }
            }


            $response->addDataSet(new DataSet("findCash", $cash));
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function validateCaixa(Request\Filter $request, Response $response) {
        try{
            $params = $request->getFilterCriteria()->getConditions();
            $licsUso = Utilities::getValueInFilterDataSourceByName($params, 'LICENCAUSO');
            $idtipLinp = Utilities::getValueInFilterDataSourceByName($params, 'IDTIPLINPC');
            $cash = $this->customizationFilesService->validateCaixa($licsUso,$idtipLinp);


            $response->addDataSet(new DataSet("findCash", [$cash]));
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function validateUseLicense(Request\Filter $request, Response $response) {
        try{
            $params = $request->getFilterCriteria()->getConditions();
            $licencauso = Utilities::getValueInFilterDataSourceByName($params, "CDLOCALUSO");
            $validate = $this->customizationFilesService->validateUseLicense($licencauso);

            $response->addDataSet(new DataSet("validate", [$validate]));
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function getLimSemPer(Request\Filter $request, Response $response) {
        try{
            ini_set('max_execution_time', '7200');
            set_time_limit(7200);
            $params = $request->getFilterCriteria()->getConditions();
            $licencauso = Utilities::getValueInFilterDataSourceByName($params, "LICENCAUSO");
            $limSemPer = InstanceProvider::getService()->getServicePerPer()->getLimSemPer($licencauso);
            //$limSemPer = $this->customizationFilesService->getLimSemPer($licencauso);
            $response->addDataSet(new DataSet("getLimSemPer", $limSemPer));
        } catch(CustomException $e) {
            $response->setError(\Util\Utilities::getErrorObjectFromException($e));
        }
    }

    public function recordContatoPer(Request\Filter $request, Response $response) {
        try{
            $result = $this->customizationFilesService->recordContatoPer();
            $response->addDataSet(new DataSet("recordContatoPer", [$result]));
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function generateNewPer(Request\Filter $request, Response $response) {
        try{
            ini_set('max_execution_time', '7200');
            set_time_limit(7200);
            $params = $request->getFilterCriteria()->getConditions();
            $lang = Utilities::getValueInFilterDataSourceByName($params, 'LANG');
            $listaTrab = Utilities::getValueInFilterDataSourceByName($params, 'LISTATRAB');
            $listaFili = Utilities::getValueInFilterDataSourceByName($params, 'LISTAFILI');
            $endMail = Utilities::getValueInFilterDataSourceByName($params, 'ENDMAIL');
            $endDate = Utilities::getValueInFilterDataSourceByName($params, 'DATA');
            $nrcontatoper = Utilities::getValueInFilterDataSourceByName($params, 'NRCONTATOPER');
            $parcial = Utilities::getValueInFilterDataSourceByName($params, 'PARCIAL');
            $idIdioma = Utilities::langForIdidioma($lang);
            $result = $this->customizationFilesService->generateNewPer($listaFili, $listaTrab, $nrcontatoper, $endMail, $idIdioma, $endDate,$parcial);
            $lista = $this->customizationFilesService->findLista($listaFili);
            $response->addDataSet(new DataSet("generateNewPer", [$result,$lista]));
        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function sendSatEmail(Request\Filter $request, Response $response) {
        try{
            $params = $request->getFilterCriteria()->getConditions();
            $cdluso = Utilities::getValueInFilterDataSourceByName($params, 'CDLUSO');
            $nmfant = Utilities::getValueInFilterDataSourceByName($params, 'NMFANTLUSO');
            $email = Utilities::getValueInFilterDataSourceByName($params, 'EMAIL');
            $cnpj = Utilities::getValueInFilterDataSourceByName($params, 'NRINSJURLUSO');
            $result = $this->customizationFilesService->sendSatEmail($cdluso, $nmfant, $email, $cnpj);
            $response->addDataSet(new DataSet("sendSatEmail", [$result]));
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function delListaTrab(Request\Filter $request, Response $response) {
        try{
            $params = $request->getFilterCriteria()->getConditions();
            $listaTrab = Utilities::getValueInFilterDataSourceByName($params, 'LISTATRAB');
            $listaFili = Utilities::getValueInFilterDataSourceByName($params, 'LISTAFILI');
            $result = $this->customizationFilesService->delListaTrab($listaFili, $listaTrab);
            $response->addDataSet(new DataSet("DelListaTrab", [$result]));
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function findPrinter(Request\Filter $request, Response $response) {
        try{
            $params = $request->getFilterCriteria()->getConditions();
            $licensaUsoId = 0;
            foreach ($params as $param) {
                $name = $param['columnName'];
                if ($name == 'LICENSAUSO') {
                    $licensaUsoId = '%'.Utilities::zeroLeftPadding($param['value'], 10).'%';
                }
            }
            $printers = $this->customizationFilesService->findPrinter($licensaUsoId);
            $response->addDataSet(new DataSet("findPrinter", $printers));
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function saveCash(Request\DataSet $request, Response $response) {
        try{
            $row = $request->getDataSet()->getRows()[0];
            $cdCaixa = $row['CDCAIXALUSO'];
            $nmCaixa = $row['NMCAIXALUSO'];
            $licensauso = Utilities::zeroLeftPadding($row['licensauso'],10);
            $this->customizationFilesService->saveCash($cdCaixa, $nmCaixa, $licensauso);
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function saveCustomizationFilesFromWebService(Request\DataSet $request, Response $response) {
        try{
            $row = $request->getDataSet()->getRows()[0];
            $cdlocaluso = $row['CDLOCALUSO'];
            $idlusoativ = empty($row['IDLUSOATIV']) ? 'S' : $row['IDLUSOATIV'];
            $nrlicencauso = Utilities::zeroLeftPadding($row['CDLOCALUSO'], 10);
            $nmfantluso = $row['NMFANTLUSO'];
            $nmrazsocluso = $row['NMRAZSOCLUSO'];
            $idtpijurluso = $row['IDTPIJURLUSO'];
            $nrinsjurluso = $row['NRINSJURLUSO'];
            $nrinsestluso = $row['NRINSESTLUSO'];
            $nrinsmuniluso = $row['NRINSMUNILUSO'];
            $nmcontluso = $row['NMCONTLUSO'];
            $nmdeptoluso = $row['NMDEPTOLUSO'];
            $idfaturafilisep = empty($row['IDFATURAFILISEP']) ? 'N' : $row['IDFATURAFILISEP'];
            $dsendeluso = $row['DSENDELUSO'];
            $nmbairluso = $row['NMBAIRLUSO'];
            $nrcepluso = $row['NRCEPLUSO'];
            $cdpais = $row['CDPAIS'];
            $sgestado = $row['SGESTADO'];
            $cdmunicipio = $row['CDMUNICIPIO'];
            $nrteleluso = $row['NRTELELUSO'];
            $nrramalluso = empty($row['NRRAMALLUSO']) ? null : $row['NRRAMALLUSO'];
            $nrfaxluso = empty($row['NRFAXLUSO']) ? null : $row['NRFAXLUSO'];
            $dsemailcomlu = empty($row['DSEMAILCOMLU']) ? null : $row['DSEMAILCOMLU'];
            $cdlinpclie = $row['CDLINPCLIE'];
            $idmodproc = empty($row['IDMODPROC']) ? 0 : $row['IDMODPROC'];
            if($idmodproc == 0){
                 $idmodproc = 'F';
            }

            $idlocaproc = empty($row['IDLOCAPROC']) ? 0 : $row['IDLOCAPROC'];
            if($row['IDLOCAPROC'] == 0){
                  $idlocaproc = 'F';
            }

            $isNew = empty($row['__is_new']) ? null : $row['__is_new'];
            $this->customizationFilesService->saveCustomizationFiles($cdlocaluso, $nmfantluso, $nmrazsocluso, $nrinsjurluso,
                $nrinsestluso, $nrinsmuniluso, $nmcontluso, $nmdeptoluso, $idfaturafilisep, $dsendeluso, $nmbairluso,
                $nrcepluso, $cdpais, $sgestado, $cdmunicipio, $nrteleluso, $nrramalluso, $nrfaxluso, $dsemailcomlu,
                $cdlinpclie, $nrlicencauso, $idmodproc, $idlocaproc, $isNew, $idlusoativ, $idtpijurluso);
        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function saveCustomizationFiles(Request\DataSet $request, Response $response) {
        try{
            $row = $request->getDataSet()->getRows()[0];
            $cdlocaluso = $row['CDLOCALUSO'];
            $idlusoativ = empty($row['IDLUSOATIV']) ? 'S' : $row['IDLUSOATIV'];
            $nrlicencauso = Utilities::zeroLeftPadding($row['CDLOCALUSO'], 10);
            $nmfantluso = $row['NMFANTLUSO'];
            $nmrazsocluso = $row['NMRAZSOCLUSO'];
            $idtpijurluso = $row['IDTPIJURLUSO'];
            $nrinsjurluso = $row['NRINSJURLUSO'];
            $nrinsestluso = $row['NRINSESTLUSO'];
            $nrinsmuniluso = $row['NRINSMUNILUSO'];
            $nmcontluso = $row['NMCONTLUSO'];
            $nmdeptoluso = $row['NMDEPTOLUSO'];
            $idfaturafilisep = empty($row['IDFATURAFILISEP']) ? 'N' : $row['IDFATURAFILISEP'];
            $dsendeluso = $row['DSENDELUSO'];
            $nmbairluso = $row['NMBAIRLUSO'];
            $nrcepluso = $row['NRCEPLUSO'];
            $cdpais = $row['CDPAIS'];
            $sgestado = $row['SGESTADO'];
            $cdmunicipio = $row['CDMUNICIPIO'];
            $nrteleluso = $row['NRTELELUSO'];
            $nrramalluso = empty($row['NRRAMALLUSO']) ? null : $row['NRRAMALLUSO'];
            $nrfaxluso = empty($row['NRFAXLUSO']) ? null : $row['NRFAXLUSO'];
            $dsemailcomlu = empty($row['DSEMAILCOMLU']) ? null : $row['DSEMAILCOMLU'];
            $cdlinpclie = $row['CDLINPCLIE'];
            $idmodproc = empty($row['IDMODPROC']) ? 0 : $row['IDMODPROC'];
            if($idmodproc == 0){
                 $idmodproc = 'F';
            }

            $idlocaproc = empty($row['IDLOCAPROC']) ? 0 : $row['IDLOCAPROC'];
            if($row['IDLOCAPROC'] == 0){
                  $idlocaproc = 'F';
            }

            $isNew = empty($row['__is_new']) ? null : $row['__is_new'];
            $this->customizationFilesService->saveCustomizationFiles($cdlocaluso, $nmfantluso, $nmrazsocluso, $nrinsjurluso,
                $nrinsestluso, $nrinsmuniluso, $nmcontluso, $nmdeptoluso, $idfaturafilisep, $dsendeluso, $nmbairluso,
                $nrcepluso, $cdpais, $sgestado, $cdmunicipio, $nrteleluso, $nrramalluso, $nrfaxluso, $dsemailcomlu,
                $cdlinpclie, $nrlicencauso, $idmodproc, $idlocaproc, $isNew, $idlusoativ, $idtpijurluso);
        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function savePrinter(Request\DataSet $request, Response $response) {
        try{
            $row = $request->getDataSet()->getRows()[0];
            $nrserimpluso = $row['NRSERIMPLUSO'];
            $nrecfimpluso = $row['NRECFIMPLUSO'];
            $cdtipoimpr = $row['CDTIPOIMPR'];
            $licensauso = Utilities::zeroLeftPadding($row['licensauso'],10);
            $this->customizationFilesService->savePrinter($nrserimpluso, $nrecfimpluso, $cdtipoimpr, $licensauso);
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function saveLegalRepresentative(Request\DataSet $request, Response $response) {
        try{
            $row = $request->getDataSet()->getRows()[0];
            $cdreprlegalempr = empty($row['CDREPRLEGALEMPR']) ? null : $row['CDREPRLEGALEMPR'];
            $nmreprlegalempr = empty($row['NMREPRLEGALEMPR']) ? null : $row['NMREPRLEGALEMPR'];
            $nrrgreprlegal = empty($row['NRRGREPRLEGAL']) ? null : $row['NRRGREPRLEGAL'];
            $cdexrgreprlegal = empty($row['CDEXRGREPRLEGAL']) ? null : $row['CDEXRGREPRLEGAL'];
            $nrtelreprlegal = empty($row['NRTELREPRLEGAL']) ? null : $row['NRTELREPRLEGAL'];
            $dsendereprlegal = empty($row['DSENDEREPRLEGAL']) ? null : $row['DSENDEREPRLEGAL'];
            $nmbairreprlegal = empty($row['NMBAIRREPRLEGAL']) ? null : $row['NMBAIRREPRLEGAL'];
            $nrcepreprlegal = empty($row['NRCEPREPRLEGAL']) ? null : $row['NRCEPREPRLEGAL'];
            $cdpais = empty($row['CDPAIS']) ? null : $row['CDPAIS'];
            $sgestado = empty($row['SGESTADO']) ? null : $row['SGESTADO'];
            $cdmunicipio = empty($row['CDMUNICIPIO']) ? null : $row['CDMUNICIPIO'];
            $nrfaxreprlegal = empty($row['NRFAXREPRLEGAL']) ? null : $row['NRFAXREPRLEGAL'];
            $nrcelreprlegal = empty($row['NRCELREPRLEGAL']) ? null : $row['NRCELREPRLEGAL'];
            $dsemailreprlegal = empty($row['DSEMAILREPRLEGAL']) ? null : $row['DSEMAILREPRLEGAL'];
            $licensauso = empty($row['licensauso']) ? null : $row['licensauso'];
            $search = empty($row['search']) ? null : $row['search'];
            $this->customizationFilesService->saveLegalRepresentative($cdreprlegalempr,$nmreprlegalempr, $nrrgreprlegal, $cdexrgreprlegal , $nrtelreprlegal,
                $dsendereprlegal, $nmbairreprlegal, $nrcepreprlegal, $cdpais, $sgestado, $cdmunicipio, $nrfaxreprlegal, $nrcelreprlegal, $dsemailreprlegal,
                $licensauso, $search);
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function removeCash(Request\Row $request, Response $response) {
        try{
            $row = $request->getRow();
            $cdCaixa = $row['CDCAIXALUSO'];
            $licensauso = Utilities::zeroLeftPadding($row['licensauso'],10);
            $this->customizationFilesService->removeCash($cdCaixa, $licensauso);
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function removePrinter(Request\Row $request, Response $response) {
        try{
            $row = $request->getRow();
            $nrserimpluso = $row['NRSERIMPLUSO'];
            $licensauso = Utilities::zeroLeftPadding($row['licensauso'],10);
            $this->customizationFilesService->removePrinter($nrserimpluso, $licensauso);
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function removeCustomizationFile(Request\Row $request, Response $response) {
        try{
            $row = $request->getRow();
            $licensauso = Utilities::zeroLeftPadding($row['CDLOCALUSO'],10);
            $this->customizationFilesService->removeCustomizationFile($licensauso);
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function findCostsPer(Request\Filter $request, Response $response)
    {
        try{
            $conditions = $request->getFilterCriteria()->getConditions();
            $page      = $request->getFilterCriteria()->getPage();
            $pageSize  = $request->getFilterCriteria()->getPageSize();
            $cdClient = Utilities::getValueInFilterDataSourceByName($conditions, 'CDCLIENTE', true);
            $costsPer = $this->customizationFilesService->findCostsPer($cdClient, $page, $pageSize, $conditions);
            $response->addDataSet(new DataSet("findCostsPer", $costsPer));
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

    public function findCostsPerGroupedFilial(Request\Filter $request, Response $response)
    {
        try{
            $conditions = $request->getFilterCriteria()->getConditions();
            $page      = $request->getFilterCriteria()->getPage();
            $pageSize  = $request->getFilterCriteria()->getPageSize();
            $cdClient = Utilities::getValueInFilterDataSourceByName($conditions, 'CDCLIENTE', true);
            $costsPer = $this->customizationFilesService->findCostsPerGroupedFilial($cdClient, $page, $pageSize, $conditions);
            $response->addDataSet(new DataSet("findCostsPerGroupedFilial", $costsPer));
        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }

}
